import { HttpService } from '@nestjs/axios';
import { Observable } from 'rxjs';
import { Delete, DeleteResult, Fetch, FetchResult, IndexStatsResult, PineconeConfig, Query, QueryResults, Update, UpdateResult, Upsert, UpsertResult } from '../interface';
export declare class PineconeVectorService {
    private readonly config;
    private readonly httpService;
    constructor(config: PineconeConfig, httpService: HttpService);
    /**
     * HttpService config
     * @private
     */
    private _conf;
    private url;
    /**
     * The DescribeIndexStats operation returns statistics about the index's contents.
     * @param index index name
     */
    describeIndexStats(index?: string): Observable<IndexStatsResult>;
    /**
     * The Query operation searches a namespace, using one or more query vectors. It retrieves the ids of the most similar items in a namespace, along with their similarity scores.
     * @param query
     * @param index
     */
    query(query: Query, index?: string): Observable<QueryResults>;
    /**
     * The Delete operation deletes vectors, by id, from a single namespace. You can delete items by their id, from a single namespace.
     * @param del
     * @param index
     */
    delete(del: Delete, index?: string): Observable<DeleteResult>;
    /**
     * The Fetch operation looks up and returns vectors, by id, from a single namespace. The returned vectors include the vector data and/or metadata.
     * @param fetch
     * @param index
     */
    fetch(fetch: Fetch, index?: string): Observable<FetchResult>;
    /**
     * The Update operation updates vector in a namespace. If a value is included, it will overwrite the previous value. If a set_metadata is included, the values of the fields specified in it will be added or overwrite the previous value.
     * @param update
     * @param index
     */
    update(update: Update, index?: string): Observable<UpdateResult>;
    /**
     * The Upsert operation writes vectors into a namespace. If a new value is upserted for an existing vector id, it will overwrite the previous value.
     * @param upsert
     * @param index
     */
    upsert(upsert: Upsert, index?: string): Observable<UpsertResult>;
}
