"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PineconeVectorService = void 0;
const common_1 = require("@nestjs/common");
const axios_1 = require("@nestjs/axios");
const rxjs_1 = require("rxjs");
const interface_1 = require("../interface");
let PineconeVectorService = class PineconeVectorService {
    constructor(config, httpService) {
        this.config = config;
        this.httpService = httpService;
        this._conf = {
            headers: {
                'Api-Key': this.config.apiKey,
                'Content-Type': 'application/json',
            },
        };
    }
    url(target, index) {
        return `https://${index ? index : this.config.index}-${this.config.project}.svc.${this.config.environment}.pinecone.io${target}`;
    }
    /**
     * The DescribeIndexStats operation returns statistics about the index's contents.
     * @param index index name
     */
    describeIndexStats(index) {
        return this.httpService
            .get(this.url('/describe_index_stats', index), this._conf)
            .pipe((0, rxjs_1.map)((axiosResponse) => {
            return axiosResponse.data;
        }));
    }
    /**
     * The Query operation searches a namespace, using one or more query vectors. It retrieves the ids of the most similar items in a namespace, along with their similarity scores.
     * @param query
     * @param index
     */
    query(query, index) {
        return this.httpService
            .post(this.url('/query', index), query, this._conf)
            .pipe((0, rxjs_1.map)((axiosResponse) => {
            return axiosResponse.data;
        }));
    }
    /**
     * The Delete operation deletes vectors, by id, from a single namespace. You can delete items by their id, from a single namespace.
     * @param del
     * @param index
     */
    delete(del, index) {
        return this.httpService
            .post(this.url('/vectors/delete', index), del, this._conf)
            .pipe((0, rxjs_1.map)((axiosResponse) => {
            return axiosResponse.data;
        }));
    }
    /**
     * The Fetch operation looks up and returns vectors, by id, from a single namespace. The returned vectors include the vector data and/or metadata.
     * @param fetch
     * @param index
     */
    fetch(fetch, index) {
        const params = '?' +
            fetch.ids.map((id) => 'ids=' + encodeURI(id)).join('&') +
            (fetch.namespace ? '&namespace=' + fetch.namespace : '');
        return this.httpService
            .get(this.url(`/vectors/fetch${params}`, index), this._conf)
            .pipe((0, rxjs_1.map)((axiosResponse) => {
            return axiosResponse.data;
        }));
    }
    /**
     * The Update operation updates vector in a namespace. If a value is included, it will overwrite the previous value. If a set_metadata is included, the values of the fields specified in it will be added or overwrite the previous value.
     * @param update
     * @param index
     */
    update(update, index) {
        return this.httpService
            .post(this.url('/vectors/update', index), update, this._conf)
            .pipe((0, rxjs_1.map)((axiosResponse) => {
            return axiosResponse.data;
        }));
    }
    /**
     * The Upsert operation writes vectors into a namespace. If a new value is upserted for an existing vector id, it will overwrite the previous value.
     * @param upsert
     * @param index
     */
    upsert(upsert, index) {
        return this.httpService
            .post(this.url('/vectors/upsert', index), upsert, this._conf)
            .pipe((0, rxjs_1.map)((axiosResponse) => {
            return axiosResponse.data;
        }));
    }
};
PineconeVectorService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, common_1.Inject)(interface_1.PINECONE_CONFIG)),
    __metadata("design:paramtypes", [Object, axios_1.HttpService])
], PineconeVectorService);
exports.PineconeVectorService = PineconeVectorService;
//# sourceMappingURL=pinecone.vector.service.js.map